FRETBursts Reference Manual
===========================

Contents:

.. toctree::
    :maxdepth: 2

    loader
    data_class
    ph_sel
    background
    burst_selection
    fit
    fret_fit
    plots
    burstsearch
    phrates
    plugins
    HDF5_format
    fretmath
    files_description
    cython
